@@ -86,7 +86,7 @@ parse_input = {'boolean': parse_bool,
 
 def parse_input_or_jbor(in_class, value):
     val_substrings = split_unescaped(':', value)
-    if len(val_substrings) == 2 and is_job_id(val_substrings[0]):
+    if len(val_substrings) == 2 and (is_job_id(val_substrings[0]) or is_localjob_id(val_substrings[0])):
         return {"job": val_substrings[0], "field": val_substrings[1]}
     else:
         if in_class.startswith('array:'):
@@ -309,7 +309,7 @@ def format_choices_or_suggestions(header, items, obj_class, initial_indent=' ' *
         # TODO: in interactive prompts the quotes here may be a bit
         # misleading. Perhaps it should be a separate mode to print
         # "interactive-ready" suggestions.
-        return fill(header + ' ' + ', '.join([pipes.quote(item) for item in items]),
+        return fill(header + ' ' + ', '.join([pipes.quote(unicode(item)) for item in items]),
                     initial_indent=initial_indent,
                     subsequent_indent=subsequent_indent)
 
@@ -385,6 +385,9 @@ def get_input_single(param_desc):
             except TypeError as details:
                 print fill('Error occurred when parsing for class ' + in_class + ': ' + unicode(details))
                 continue
+            if 'choices' in param_desc and value not in param_desc['choices']:
+                print fill(RED() + BOLD() + 'Warning:' + ENDC() + ' value "' + unicode(value) + '" for input ' + WHITE()
+                           + BOLD() + param_desc['name'] + ENDC() + ' is not in the list of choices for that input')
             return value
     except EOFError:
         raise Exception('')
@@ -395,14 +398,17 @@ def get_optional_input_str(param_desc):
     return param_desc.get('label', param_desc['name']) + ' (' + param_desc['name'] + ')'
 
 class ExecutableInputs(object):
-    def __init__(self, executable=None, input_name_prefix=None):
+    def __init__(self, executable=None, input_name_prefix=None, input_spec=None):
         self.executable = executable
         self._desc = {} if self.executable is None else executable.describe()
-        self.input_spec = collections.OrderedDict() if 'inputSpec' in self._desc else None
+        self.input_spec = collections.OrderedDict() if 'inputSpec' in self._desc or input_spec else None
         self.required_inputs, self.optional_inputs, self.array_inputs = [], [], set()
         self.input_name_prefix = input_name_prefix
 
-        for spec_atom in self._desc.get('inputSpec', []):
+        if input_spec is None:
+            input_spec = self._desc.get('inputSpec', [])
+
+        for spec_atom in input_spec:
             if spec_atom['class'].startswith('array:'):
                 self.array_inputs.add(spec_atom['name'])
             self.input_spec[spec_atom['name']] = spec_atom
@@ -445,7 +451,7 @@ class ExecutableInputs(object):
             try:
                 # Resolve "job-xxxx:output-name" syntax into a canonical job ref
                 job_id, field = split_unescaped(':', input_value)
-                if is_job_id(job_id):
+                if is_job_id(job_id) or is_localjob_id(job_id):
                     input_value = {"job": job_id, "field": field}
                     done = True
             except:
